==> haskell-tasty-hspec-1.2.0.3-38-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-hspec
version:              1.2.0.3
visibility:           public
id:                   tasty-hspec-1.2.0.3-4bwdmp7qscpGlGlpGia8h4
key:                  tasty-hspec-1.2.0.3-4bwdmp7qscpGlGlpGia8h4
license:              BSD-3-Clause
maintainer:           mitchellwrosen@gmail.com
author:               Mitchell Rosen
homepage:             https://github.com/mitchellwrosen/tasty-hspec
synopsis:             Hspec support for the Tasty test framework.
description:
    This package provides a Tasty provider for Hspec test
    suites.

category:             Testing
abi:                  8fafe521988c88d989fb2a07bd82cc09
exposed:              True
exposed-modules:      Test.Tasty.Hspec
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-hspec-1.2.0.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-hspec-1.2.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hspec
hs-libraries:         HStasty-hspec-1.2.0.3-4bwdmp7qscpGlGlpGia8h4
depends:
    QuickCheck-2.14.3-1kHSJYV22r9H1CQAFEYDgg base-4.16.4.0
    hspec-2.10.9-HkStsyOeCMWCqrIlfVYjmC
    hspec-core-2.10.9-7yO45d4zctM4pxLO6U8zpB
    tasty-1.4.3-7mwiS20bCN4I3SJ3l4eJAB
    tasty-quickcheck-0.10.2-5b190LAe6Hq2TOMhIqyyBv
    tasty-smallcheck-0.8.2-HYnM2nw1KHpC69eEgsoLAY

haddock-interfaces:   /usr/share/doc/haskell-tasty-hspec/html/tasty-hspec.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hspec/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-hspec-1.2.0.3-39-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-hspec
version:              1.2.0.3
visibility:           public
id:                   tasty-hspec-1.2.0.3-E0B3Tnmr8tzLEOY4Zz8Tl1
key:                  tasty-hspec-1.2.0.3-E0B3Tnmr8tzLEOY4Zz8Tl1
license:              BSD-3-Clause
maintainer:           mitchellwrosen@gmail.com
author:               Mitchell Rosen
homepage:             https://github.com/mitchellwrosen/tasty-hspec
synopsis:             Hspec support for the Tasty test framework.
description:
    This package provides a Tasty provider for Hspec test
    suites.

category:             Testing
abi:                  2c375135dcbacaf09b1f465e23495a67
exposed:              True
exposed-modules:      Test.Tasty.Hspec
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-hspec-1.2.0.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-hspec-1.2.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hspec
hs-libraries:         HStasty-hspec-1.2.0.3-E0B3Tnmr8tzLEOY4Zz8Tl1
depends:
    QuickCheck-2.14.3-4ByVFEBmTRSJjm02AG2pXb base-4.16.4.0
    hspec-2.10.9-79gelxnYVeZ7pGeaoBOQA
    hspec-core-2.10.9-46iY0XuXwGZ2OnLkFKtXTW
    tasty-1.4.3-HG1lp3DnHkK33QKXUVI3A7
    tasty-quickcheck-0.10.2-1FUgv9U5ZOiDkRAMco8rEo
    tasty-smallcheck-0.8.2-8tKqoeN3FjUHtvhSkXpHwk

haddock-interfaces:   /usr/share/doc/haskell-tasty-hspec/html/tasty-hspec.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hspec/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
